==> haskell-quickcheck-io-0.2.0-579-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-KZvjsWYotGlCmn4MWP0wUs
key:                  quickcheck-io-0.2.0-KZvjsWYotGlCmn4MWP0wUs
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  18d423c46970df1ec8c627b648d97716
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.0.2/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-KZvjsWYotGlCmn4MWP0wUs
depends:
    HUnit-1.6.2.0-27H1uGAvNhf3XwNqk0T4b4
    QuickCheck-2.14.2-7guLpRHd3ylH0mq22c2g84 base-4.15.1.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-io-0.2.0-586-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-jxqzXaUyEUFIMaNrgQeWI
key:                  quickcheck-io-0.2.0-jxqzXaUyEUFIMaNrgQeWI
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  a2803c81da284beb0ed236779a8a9fce
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.0.2/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-jxqzXaUyEUFIMaNrgQeWI
depends:
    HUnit-1.6.2.0-GxHj7QRrIr61777X28R6NT
    QuickCheck-2.14.2-JTbsW3unr4f1lZKwXKui6J base-4.15.1.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
